@@ -1,6 +1,6 @@
 ;;;; -*- emacs-lisp -*-
 ;;;; GNU Mailutils -- a suite of utilities for electronic mail
-;;;; Copyright (C) 2003, 2007, 2010-2012, 2014-2016 Free Software
+;;;; Copyright (C) 2003, 2007, 2010-2012, 2014-2018 Free Software
 ;;;; Foundation, Inc.
 ;;;; 
 ;;;; GNU Mailutils is free software; you can redistribute it and/or modify
@@ -16,7 +16,7 @@
 ;;;; You should have received a copy of the GNU General Public License
 ;;;; along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. 
 
-(setq mh-progs "/usr/bin")
+(setq mh-progs "/usr/bin/mu-mh")
 (setq mh-lib "/usr/share/mailutils/mh")
 (setq mh-lib-progs mh-progs)
 (load "mh-e")
